<?php

namespace Drupal\podcast_publisher_analytics\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Field\BaseFieldDefinition;

/**
 * Defines the DownloadIntent entity.
 *
 * @ContentEntityType(
 *   id = "podcast_download_intent",
 *   label = @Translation("Podcast Download Intent"),
 *   base_table = "podcast_download_intent",
 *   entity_keys = {
 *     "id" = "id",
 *     "uuid" = "uuid",
 *   },
 * )
 */
class DownloadIntent extends ContentEntityBase {

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    // Standard field, used as unique if primary index.
    $fields['id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the Download Intent entity.'))
      ->setReadOnly(TRUE);

    // Standard field, unique outside the scope of the current project.
    $fields['uuid'] = BaseFieldDefinition::create('uuid')
      ->setLabel(t('UUID'))
      ->setDescription(t('The UUID of the Download Intent entity.'))
      ->setReadOnly(TRUE);

    $fields['requester_id'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Requester ID'))
      ->setDescription(t('The ID of the requester.'))
      ->setRequired(TRUE);

    $fields['user_agent_string'] = BaseFieldDefinition::create('string')
      ->setLabel(t('User Agent String'))
      ->setDescription(t('The raw user agent string.'));

    $fields['user_agent'] = BaseFieldDefinition::create('entity_reference')
      ->setTargetEntityTypeId('podcast_user_agent')
      ->setLabel(t('User Agent'))
      ->setDescription(t('The User Agent'));

    $fields['source'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Source'))
      ->setDescription(t('The request\'s source'));

    $fields['media'] = BaseFieldDefinition::create('entity_reference')
      ->setTargetEntityTypeId('media')
      ->setLabel(t('Media ID Reference'))
      ->setDescription(t('ID of referenced podcast episode media.'));

    $fields['file'] = BaseFieldDefinition::create('entity_reference')
      ->setTargetEntityTypeId('file')
      ->setLabel(t('File ID Reference'))
      ->setDescription(t('ID of referenced audio file.'));

    $fields['geo_area'] = BaseFieldDefinition::create('entity_reference')
      ->setTargetEntityTypeId('podcast_geo_area')
      ->setLabel(t('Geo Area ID Reference'))
      ->setDescription(t('ID of requester\'s geo area.'));

    $fields['lat'] = BaseFieldDefinition::create('float')
      ->setLabel(t('Latitude'))
      ->setDescription(t('The latitude of the requester.'));

    $fields['lng'] = BaseFieldDefinition::create('float')
      ->setLabel(t('Longitude'))
      ->setDescription(t('The longitude of the requester.'));

    $fields['timestamp'] = BaseFieldDefinition::create('timestamp')
      ->setLabel(t('Timestamp'))
      ->setDescription('The timestamp of the file request.');

    $fields['httprange'] = BaseFieldDefinition::create('string')
      ->setLabel(t('HTTPRange'))
      ->setDescription(t('HTTP Header\'s range of bytes that were requested.'));

    $fields['processed'] = BaseFieldDefinition::create('boolean')
      ->setDefaultValue(FALSE)
      ->setLabel(t('Processed'))
      ->setDescription(t('Indicator whether requester ID was already processed to be anonymous.'));

    return $fields;
  }

}
