<?php

namespace Drupal\podcast_publisher_analytics\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a Block to render charts to podcast episode.
 *
 * @Block(
 *   id = "podcast_episode_chart_block",
 *   admin_label = @Translation("Podcast Episode Chart Block"),
 *   category = @Translation("Podcast Publisher"),
 * )
 */
class ChartBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * The download intent data service.
   *
   * @var \Drupal\podcast_publisher_analytics\DownloadIntentDataService
   */
  protected $downloadIntentDataService;

  /**
   * The route match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected $routeMatch;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    $instance = new static($configuration, $plugin_id, $plugin_definition);
    $instance->downloadIntentDataService = $container->get('podcast_publisher_analytics.data_service');
    $instance->routeMatch = $container->get('current_route_match');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $count = 0;
    if ($media = $this->routeMatch->getParameter('media')) {
      $count = $this->downloadIntentDataService->getCountOfAllDownloads($media);
    }
    // TODO: Come up with a caching strategy.
    return [
      '#markup' => $count,
      '#cache' => [
        'max_age' => 0,
      ],
    ];
  }

}
